==> opensearch-py-2.7.1.gh.tar.gz: opensearch-py-2.7.1/MAINTAINERS.md <==
## Overview

This document contains a list of maintainers in this repo. See [opensearch-project/.github/RESPONSIBILITIES.md](https://github.com/opensearch-project/.github/blob/main/RESPONSIBILITIES.md#maintainer-responsibilities) that explains what the role of maintainer means, what maintainers do in this and other repos, and how they should be doing it. If you're interested in contributing, and becoming a maintainer, see [CONTRIBUTING](CONTRIBUTING.md).

## Current Maintainers

| Maintainer                | GitHub ID                                           | Affiliation |
| ------------------------- | --------------------------------------------------- | ----------- |
| Vacha Shah                | [VachaShah](https://github.com/VachaShah)           | Amazon      |
| Daniel Doubrovkine        | [dblock](https://github.com/dblock)                 | Amazon      |
| Harsha Vamsi Kalluri      | [harshavamsi](https://github.com/harshavamsi)       | Amazon      |
| Aleksei Atavin            | [axeoman](https://github.com/axeoman)               | Aiven       |
| Denis Zalevskiy           | [deztructor](https://github.com/deztructor)         | Aiven       |
| Shephali Mittal           | [Shephalimittal](https://github.com/Shephalimittal) | Amazon      |
| Sai Medhini Reddy Maryada | [saimedhi](https://github.com/saimedhi)             | Amazon      |
| Florian Vazelle           | [florianvazelle](https://github.com/florianvazelle) | harfanglab  |

## Emeritus

| Maintainer    | GitHub ID                               | Affiliation |
| ------------- | --------------------------------------- | ----------- |
| Rushi Agrawal | [rushiagr](https://github.com/rushiagr) | Amazon      |

==> opensearch-py-3.0.0.gh.tar.gz: opensearch-py-3.0.0/MAINTAINERS.md <==
## Overview

This document contains a list of maintainers in this repo. See [opensearch-project/.github/RESPONSIBILITIES.md](https://github.com/opensearch-project/.github/blob/main/RESPONSIBILITIES.md#maintainer-responsibilities) that explains what the role of maintainer means, what maintainers do in this and other repos, and how they should be doing it. If you're interested in contributing, and becoming a maintainer, see [CONTRIBUTING](CONTRIBUTING.md).

## Current Maintainers

| Maintainer                | GitHub ID                                           | Affiliation |
| ------------------------- | --------------------------------------------------- | ----------- |
| Vacha Shah                | [VachaShah](https://github.com/VachaShah)           | Amazon      |
| Daniel Doubrovkine        | [dblock](https://github.com/dblock)                 | Independent |
| Harsha Vamsi Kalluri      | [harshavamsi](https://github.com/harshavamsi)       | Amazon      |
| Aleksei Atavin            | [axeoman](https://github.com/axeoman)               | Aiven       |
| Denis Zalevskiy           | [deztructor](https://github.com/deztructor)         | Aiven       |
| Shephali Mittal           | [Shephalimittal](https://github.com/Shephalimittal) | Amazon      |
| Sai Medhini Reddy Maryada | [saimedhi](https://github.com/saimedhi)             | Amazon      |
| Florian Vazelle           | [florianvazelle](https://github.com/florianvazelle) | harfanglab  |

## Emeritus

| Maintainer    | GitHub ID                               | Affiliation |
| ------------- | --------------------------------------- | ----------- |
| Rushi Agrawal | [rushiagr](https://github.com/rushiagr) | Amazon      |
